@@ -320,7 +320,7 @@ class VOCAnnotation(VOCLabel):
         if self._annotation_path:
             return self._annotation_path
         elif self.filename:  # default value
-            return os_path.join(os_path.dirname(self.folder, full_path=False), ANNOTATION_FOLDER_DEFAULT_NAME,
+            return os_path.join(os_path.dirname(self.folder, full_path=True), ANNOTATION_FOLDER_DEFAULT_NAME,
                                 self.filename + ".json")
         return None
 
@@ -331,8 +331,8 @@ class VOCAnnotation(VOCLabel):
 
     @property
     def filename(self):
-        if self.annotation_path:
-            return os_path.get_filename(self.annotation_path)
+        if self._annotation_path:
+            return os_path.get_filename(self._annotation_path)
         if self.image_path:
             return os_path.get_filename(self.image_path)
         return None
@@ -461,7 +461,7 @@ class VOCAnnotation(VOCLabel):
 
         os_path.make_dir(os_path.dirname(filepath))
 
-        with open(filepath + ".json", "w+") as f:
+        with open(filepath, "w+") as f:
             f.write(json.dumps(self.to_dic(recursively=True), cls=VOCJSONEncoder))
         logger.debug(f"Json {filepath} exported.")
 
@@ -611,20 +611,20 @@ class VOCAnnotationSet(VOCLabel):
         # load from dir or jsons or json
         if dir_or_file:
             if isinstance(dir_or_file, list) and all(os_path.isfile(x) for x in dir_or_file):
-                self.load_from_jsons(dir_or_file, debug=debug,
+                self.load_from_jsons(sorted(dir_or_file), debug=debug,
                                      for_classification=for_classification, image_dir=image_dir)
             elif os_path.isdir(dir_or_file) or \
                     (isinstance(dir_or_file, list) and all(os_path.isdir(x) for x in dir_or_file)):
                 if os_path.isdir(dir_or_file):
-                    label_files = os_path.list_dir(dir_or_file, extension=".json", sort=True)
+                    label_files = os_path.list_dir(dir_or_file, extension=".json")
                 else:
                     label_files = []
                     for lf in dir_or_file:
-                        label_files += os_path.list_dir(lf, extension=".json", sort=True)
+                        label_files += os_path.list_dir(lf, extension=".json")
                 if not label_files:
                     label_files = os_path.list_dir(os_path.join(dir_or_file, ANNOTATION_FOLDER_DEFAULT_NAME),
-                                                   extension=".json", sort=True)
-                self.load_from_jsons(label_files, debug=debug, for_classification=for_classification,
+                                                   extension=".json")
+                self.load_from_jsons(sorted(label_files), debug=debug, for_classification=for_classification,
                                      image_dir=image_dir)
             else:  # is file
                 raise NotImplemented
